==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>カスタムプロパティを追加</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>値:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1320"/>
        <source>*VARIES*</source>
        <translation>*VARIES*</translation>
    </message>
    <message>
        <location line="-1132"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translation>選択なし</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translation type="vanished">ジオメトリ</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>依存エンティティ</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>目次</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>選択したオブジェクトからこのプロパティを削除</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>全て</translation>
    </message>
    <message>
        <location line="+641"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translation type="obsolete">カスタムプロパティを追加</translation>
    </message>
    <message>
        <location line="-619"/>
        <source>Add custom property to selected objects</source>
        <translation>選択したオブジェクトにカスタムプロパティを追加</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location line="+123"/>
        <source>Use auto measurement</source>
        <translation>自動計測を使用</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>プロパティエディタ</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>選択:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">全般</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">選択内容を新規画層に移動</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>扱い:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>カスタムプロパティを追加</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>値:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1392"/>
        <source>*VARIES*</source>
        <translation>*VARIES*</translation>
    </message>
    <message>
        <location line="-1199"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>No Selection</source>
        <translation>選択なし</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translation type="vanished">ジオメトリ</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>固有のプロパティ</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>依存エンティティ</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>目次</translation>
    </message>
    <message>
        <location line="+77"/>
        <source>Remove this property from selected objects</source>
        <translation>選択したオブジェクトからこのプロパティを削除</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>全て</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show all properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+621"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translation type="obsolete">カスタムプロパティを追加</translation>
    </message>
    <message>
        <location line="-667"/>
        <source>Add custom property to selected objects</source>
        <translation>選択したオブジェクトにカスタムプロパティを追加</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Use auto measurement</source>
        <translation>自動計測を使用</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <location line="+336"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>プロパティエディタ</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>選択:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">全般</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>一般プロパティ</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>色:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">選択内容を新規画層に移動</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>ラインタイプスケール:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>保護されています:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>扱い:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Z座標の表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>現在のブロックと現在のレイヤーのプロパティを表示</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Allow adding custom properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Always show all properties (this may slow down selection of entities)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
